﻿window.indexedDB = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
window.IDBTransaction = window.IDBTransaction || window.webkitIDBTransaction || window.msIDBTransaction;
window.IDBKeyRange = window.IDBKeyRange || window.webkitIDBKeyRange || window.msIDBKeyRange

if (!window.indexedDB)
{
	window.alert("Your browser doesn't support a stable version of IndexedDB.")
}

var db;

initDb = function (cb)
{
	var request = window.indexedDB.open("newDatabase", 4);

	clearAllData = function ()
	{
		confirmDialog("Delete all data", "Are you sure you want to delete all data?", function ()
		{
			window.localStorage.clear();
			location.reload();
			window.indexedDB.deleteDatabase("newDatabase");
		}, function ()
		{

		});
	}

	request.onerror = function (event)
	{
		console.log("error: ");
	};

	request.onsuccess = function (event)
	{
		db = request.result;
		console.log("success: " + db);
		cb(db);
	};

	// This event is only implemented in recent browsers
	request.onupgradeneeded = function (event)
	{
		//The IDBDatabase interface 
		var db = event.target.result;
		// Create an objectStore for this database
		if (event.oldVersion<2)
			db.createObjectStore("books", { keyPath: "id" });
		if (event.oldVersion<3)
			db.createObjectStore("bookmarks", { keyPath: "id" });
        if (event.oldVersion < 4)
            db.createObjectStore("misc", { keyPath: "id" });
	};
}

getBooks = function (callback)
{
	var transaction = db.transaction(['books'], 'readwrite');
	var objStore = transaction.objectStore('books');
	var keyRange = IDBKeyRange.lowerBound(0);
	var cursorRequest = objStore.openCursor(keyRange);
	var books = [];

	transaction.oncomplete = function (e)
	{
		// Execute the callback function.
		callback(books);
	};

	cursorRequest.onsuccess = function (e)
	{
		var result = e.target.result;
		if (!!result == false)
		{
			return;
		}
		books.push(result.value);
		result.continue();
	};
};

addBook = function (id, text, callback)
{
	// Initiate a new transaction.
	var transaction = db.transaction(['books'], 'readwrite');

	// Get the datastore.
	var objStore = transaction.objectStore('books');

	// Create an object for the todo item.
	var book = {
		'id': id,
		'text': text,
	};

	// Create the datastore request.
	var request = objStore.put(book);

	// Handle a successful datastore put.
	request.onsuccess = function (e)
	{
		// Execute the callback function.
		callback(book);
	};
}

getBook = function (id, callback)
{
	// Initiate a new transaction.
	var transaction = db.transaction(['books'], 'readwrite');

	// Get the datastore.
	var objStore = transaction.objectStore('books');

	// Create the datastore request.
	var request = objStore.get(id);

	// Handle a successful datastore put.
	request.onsuccess = function (e)
	{
		// Execute the callback function.
		callback(request.result);
	};
}

setDBMisc = function (id, val, callback) {
    // Initiate a new transaction.
    var transaction = db.transaction(['misc'], 'readwrite');

    // Get the datastore.
    var objStore = transaction.objectStore('misc');

    // Create an object for the todo item.
    var item = {
        'id': id,
        'val': val,
    };

    // Create the datastore request.
    var request = objStore.put(item);

    // Handle a successful datastore put.
    request.onsuccess = function (e) {
        // Execute the callback function.
        callback(item);
    };
}


getDBMisc = function (id, callback) {
    // Initiate a new transaction.
    var transaction = db.transaction(['misc'], 'readwrite');

    // Get the datastore.
    var objStore = transaction.objectStore('misc');

    // Create the datastore request.
    var request = objStore.get(id);

    // Handle a successful datastore put.
    request.onsuccess = function (e) {
        // Execute the callback function.
        callback(request.result);
    };
}

setBookmarks = function (id, bookmarks, callback)
{
	// Initiate a new transaction.
	var transaction = db.transaction(['bookmarks'], 'readwrite');

	// Get the datastore.
	var objStore = transaction.objectStore('bookmarks');

	// Create an object for the todo item.
	var book = {
		'id': id,
		'bookmarks': bookmarks,
	};

	// Create the datastore request.
	var request = objStore.put(book);

	// Handle a successful datastore put.
	request.onsuccess = function (e)
	{
		// Execute the callback function.
		callback(book);
	};
}

getBookmarks = function (id, callback)
{
	// Initiate a new transaction.
	var transaction = db.transaction(['bookmarks'], 'readwrite');

	// Get the datastore.
	var objStore = transaction.objectStore('bookmarks');

	// Create the datastore request.
	var request = objStore.get(id);

	// Handle a successful datastore put.
	request.onsuccess = function (e)
	{
		// Execute the callback function.
		callback(request.result);
	};
}

deleteBook = function (id, callback)
{
	// Initiate a new transaction.
	var transaction = db.transaction(['books'], 'readwrite');

	// Get the datastore.
	var objStore = transaction.objectStore('books');

	// Create the datastore request.
	var request = objStore.delete(id);

	// Handle a successful datastore put.
	request.onsuccess = function (e)
	{
		// Execute the callback function.
		callback(request.result);
	};

	deleteBookmarks(id, function () { });
}

deleteBookmarks = function (id, callback)
{
	// Initiate a new transaction.
	var transaction = db.transaction(['bookmarks'], 'readwrite');

	// Get the datastore.
	var objStore = transaction.objectStore('bookmarks');

	// Create the datastore request.
	var request = objStore.delete(id);

	// Handle a successful datastore put.
	request.onsuccess = function (e)
	{
		// Execute the callback function.
		callback(request.result);
	};
}


