﻿Swipe = 
{
	"constructor": function(element, config)
	{
		this.threshold = 10;

		if (config != null)
		{
			this.threshold = config.threshold;
		}

		this.xDown = null;
		this.yDown = null;
		this.element = typeof (element) === 'string' ? document.querySelector(element) : element;

		this.element.addEventListener('touchstart', function (evt)
		{
			this.end = evt.touches[0];
			this.xDown = evt.touches[0].clientX;
			this.yDown = evt.touches[0].clientY;
		}.bind(this), false);

		this.element.addEventListener('mousedown', function (evt)
		{
			this.xDown = evt.clientX;
			this.yDown = evt.clientY;
		}.bind(this), false);

	},

	"onLeft" : function(callback)
	{
		this.onLeft = callback;

		return this;
	},

	"onRight" : function(callback)
	{
		this.onRight = callback;

		return this;
	},

	"onUp" : function(callback)
	{
		this.onUp = callback;

		return this;
	},

	"onDown": function(callback)
	{
		this.onDown = callback;

		return this;
	},

	"handleTouchMove": function(evt)
	{
		if (!this.xDown || !this.yDown)
		{
			return;
		}

		var xUp = evt.clientX;
		var yUp = evt.clientY;

		this.xDiff = this.xDown - xUp;
		this.yDiff = this.yDown - yUp;

		var screenSize = Math.max($(window).width(), $(window).height());

		if (Math.abs(this.xDiff) > screenSize * this.threshold ||
			Math.abs(this.yDiff) > screenSize * this.threshold)
		{
			if (Math.abs(this.xDiff) > Math.abs(this.yDiff))
			{ // Most significant.
				if (this.xDiff > 0)
				{
					if (this.onLeft != null)
						this.onLeft();
				} else
				{
					if (this.onRight != null)
						this.onRight();
				}
			} else
			{
				if (this.yDiff > 0)
				{
					if (this.onUp != null)
						this.onUp();
				} else
				{
					if (this.onDown != null)
						this.onDown();
				}
			}
		}

		// Reset values.
		this.xDown = null;
		this.yDown = null;
	},

	"run" : function()
	{
		this.element.addEventListener('touchmove', function (evt)
		{
			this.end = evt.touches[0];
		}.bind(this), false);
		this.element.addEventListener('touchend', function (evt)
		{
			this.handleTouchMove(this.end);
		}.bind(this), false);
		this.element.addEventListener('mouseup', function (evt)
		{
			this.handleTouchMove(evt);
		}.bind(this), false);
	}
}